# Abaqus Model Database

Mdb commands are used to create and upgrade an Abaqus model database that stores models and analysis controls.

```{toctree}
:caption: Objects in Mdb
:maxdepth: 1

mdb/model
mdb/job
mdb/annotation
mdb/edit_mesh
```

## Classes

### Mdb

```{eval-rst}
.. autoclass:: abaqus.Mdb.Mdb.Mdb
   :members:
   :special-members: __init__
   :show-inheritance:

   .. autoclasstoc::
```

### MdbBase

```{eval-rst}
.. autoclass:: abaqus.Mdb.MdbBase.MdbBase
   :members:
   :special-members: __init__
   :show-inheritance:

   .. autoclasstoc::
```

### AcisMdb

```{eval-rst}
.. autoclass:: abaqus.Part.AcisMdb.AcisMdb
   :members:
   :special-members: __init__
   :show-inheritance:

   .. autoclasstoc::
```

### JobMdb

```{eval-rst}
.. autoclass:: abaqus.Job.JobMdb.JobMdb
   :members:
   :special-members: __init__
   :show-inheritance:

   .. autoclasstoc::
```
